define(['exports'], (function (exports) { 'use strict';

  function bar() {
    console.log('bar');
  }

  exports.bar = bar;

}));
